==> kopete-otr-trinity-3.5.13.2.tar.xz: kopete-otr-trinity-3.5.13.2/src/otrpreferences.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Michael Zanetti
 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef OTRPREFERECES_H
#define OTRPREFERECES_H

#include <kcmodule.h>
#include "otrlconfinterface.h"

/**
 * Preference widget for the OTR plugin
 * @author Michael Zanetti
 */

class OTRPreferences : public KCModule  {
   Q_OBJECT
  TQ_OBJECT

public:
	OTRPreferences(TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList());
	~OTRPreferences();

private:
	OTRPrefsUI *preferencesDialog;
	OtrlConfInterface *otrlConfInterface;
	TQMap<int, int> privKeys;

private slots: // Public slots
	void generateFingerprint();
	void showPrivFingerprint(int accountnr);
	void verifyFingerprint();
	void fillFingerprints();
	void updateButtons(int row, int col);
	void forgetFingerprint();

};


class TQAlignTableItem : public TQTableItem {

public :
	TQAlignTableItem(TQTable *table, EditType editType, const TQString& text, int alignment);

private :
	int align;
};

#endif

==> kopete-otr-trinity-14.0.7.tar.xz: kopete-otr-trinity-14.0.7/src/otrpreferences.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Michael Zanetti
 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef OTRPREFERECES_H
#define OTRPREFERECES_H

#include <tdecmodule.h>
#include "otrlconfinterface.h"

/**
 * Preference widget for the OTR plugin
 * @author Michael Zanetti
 */

class OTRPreferences : public TDECModule  {
   Q_OBJECT
  

public:
	OTRPreferences(TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList());
	~OTRPreferences();

private:
	OTRPrefsUI *preferencesDialog;
	OtrlConfInterface *otrlConfInterface;
	TQMap<int, int> privKeys;

private slots: // Public slots
	void generateFingerprint();
	void showPrivFingerprint(int accountnr);
	void verifyFingerprint();
	void fillFingerprints();
	void updateButtons(int row, int col);
	void forgetFingerprint();

};


class TQAlignTableItem : public TQTableItem {

public :
	TQAlignTableItem(TQTable *table, EditType editType, const TQString& text, int alignment);

private :
	int align;
};

#endif
